==> migrate_wizard-1.0.8-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWLinkField.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'link_field' field type.
 *
 * @FieldType(
 *   id = "link_field",
 * )
 */
class FieldTypeMWLinkField extends FieldTypeMWBase {

  public static function getMigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $field_collection = NULL) {

    $array_config = [];
    if ($data_field["destiny"] == 'social_media_links') {
      if (!isset($wildcard_yml_config['process']['pseudo_' . $data_field['destiny']])) {
        $array_config['pseudo_' . $origin_field][] = [
          'plugin' => 'skip_on_empty',
          'source' => $origin_field . '_url',
          'method' => 'process',
        ];
        $array_config['pseudo_' . $origin_field][] = [
          'plugin' => 'social_media_links',
        ];
        $array_config['pseudo_' . $data_field['destiny']][] = [
          'plugin' => 'skip_on_empty',
          'source' => ['@pseudo_' . $origin_field],
          'method' => 'process',
        ];

        $array_config[$data_field['destiny']][] = [
          'plugin' => 'skip_on_empty',
          'source' => '@pseudo_' . $data_field['destiny'],
          'method' => 'process',
        ];
        $array_config[$data_field['destiny']][] = [
          'plugin' => 'sub_process',
          'method' => 'process',
          'process' => ['link' => 'link', 'social' => 'social'],
        ];
      }
      else {
        $insert_value = [
          'plugin' => 'skip_on_empty',
          'source' => $origin_field . '_url',
          'method' => 'process',
        ];
        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], 'pseudo_' . $data_field['destiny'], 'pseudo_' . $origin_field, $insert_value);
        $wildcard_yml_config['process']['pseudo_' . $origin_field][] = [
          'plugin' => 'social_media_links',
        ];
        $wildcard_yml_config['process']['pseudo_' . $data_field['destiny']][0]['source'][] = '@pseudo_' . $origin_field;
      }
    }
    else {
      // @todo unserialize attributes d7, map to d10 and serialize
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'skip_on_empty',
        'source' => [$origin_field . '_url', $origin_field . '_title'],
        'method' => 'process',
      ];
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'field_link_value',
      ];
    }
    if(!$field_collection){
      $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
    }else{
      foreach($array_config[$data_field['destiny']] as $value){
        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], $field_collection, $data_field['destiny'], $value);
      }
    }

//    if ($data_field["destiny"] == 'social_media_links') {
//      if (!isset($wildcard_yml_config['process']['pseudo_' . $data_field['destiny']])) {
//        $wildcard_yml_config['process']['pseudo_' . $origin_field][] = [
//          'plugin' => 'skip_on_empty',
//          'source' => $origin_field . '_url',
//          'method' => 'process',
//        ];
//        $wildcard_yml_config['process']['pseudo_' . $origin_field][] = [
//          'plugin' => 'social_media_links',
//        ];
//        $wildcard_yml_config['process']['pseudo_' . $data_field['destiny']][] = [
//          'plugin' => 'skip_on_empty',
//          'source' => ['@pseudo_' . $origin_field],
//          'method' => 'process',
//        ];
//
//        $wildcard_yml_config['process'][$data_field['destiny']][] = [
//          'plugin' => 'skip_on_empty',
//          'source' => '@pseudo_' . $data_field['destiny'],
//          'method' => 'process',
//        ];
//        $wildcard_yml_config['process'][$data_field['destiny']][] = [
//          'plugin' => 'sub_process',
//          'method' => 'process',
//          'process' => ['link' => 'link', 'social' => 'social'],
//        ];
//      }
//      else {
//        $insert_value = [
//          'plugin' => 'skip_on_empty',
//          'source' => $origin_field . '_url',
//          'method' => 'process',
//        ];
//
//        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], 'pseudo_' . $data_field['destiny'], 'pseudo_' . $origin_field, $insert_value);
//
//        $wildcard_yml_config['process']['pseudo_' . $origin_field][] = [
//          'plugin' => 'social_media_links',
//        ];
//        $wildcard_yml_config['process']['pseudo_' . $data_field['destiny']][0]['source'][] = '@pseudo_' . $origin_field;
//      }
//    }
//    else {
//      // @todo unserialize attributes d7, map to d10 and serialize
//      $wildcard_yml_config['process'][$data_field['destiny']][] = [
//        'plugin' => 'skip_on_empty',
//        'source' => [$origin_field . '_url', $origin_field . '_title'],
//        'method' => 'process',
//      ];
//      $wildcard_yml_config['process'][$data_field['destiny']][] = [
//        'plugin' => 'field_link_value',
//      ];
//    }
  }

  public function addQueryByType($alias, $table, $data_field, $wildcard, $translation, $field_collection = NULL) {

    $base_field = str_replace('field_data_', '', $table);

    if($field_collection == NULL){
      $wildcard->query->leftJoin($table, $alias, "{$wildcard->getValue('leftJoinTable')} = $alias.entity_id AND $alias.entity_type = '{$wildcard->getValue('entityType')}' AND $alias.bundle = '{$wildcard->getValue('bundle')}'");
    }else{
      $wildcard->query->leftJoin($table, $alias, "{$field_collection['left_join_table']} = $alias.entity_id AND $alias.entity_type = 'field_collection_item' AND $alias.bundle = '{$field_collection['bundle']}'");
    }

    $wildcard->query->addExpression("GROUP_CONCAT(DISTINCT CONCAT (COALESCE($alias.{$base_field}_url, '')) ORDER BY $alias.delta ASC SEPARATOR '|')", $base_field.'_url', []);
    $wildcard->query->addExpression("GROUP_CONCAT(DISTINCT CONCAT (COALESCE($alias.{$base_field}_title, '')) ORDER BY $alias.delta ASC SEPARATOR '|')", $base_field.'_title', []);
    $wildcard->query->addExpression("GROUP_CONCAT(DISTINCT CONCAT (COALESCE($alias.{$base_field}_attributes, '')) ORDER BY $alias.delta ASC SEPARATOR '|')", $base_field.'_attributes', []);
  }

}

==> migrate_wizard-1.0.19-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWLinkField.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'link_field' field type.
 *
 * @FieldType(
 *   id = "link_field",
 * )
 */
class FieldTypeMWLinkField extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL) {

    $array_config = [];
    if ($data_field["destiny"] == 'social_media_links') {
      if (!isset($wildcard_yml_config['process']['pseudo_' . $data_field['destiny']])) {
        $array_config['pseudo_' . $origin_field][] = [
          'plugin' => 'skip_on_empty',
          'source' => $origin_field,
          'method' => 'process',
        ];
        $array_config['pseudo_' . $origin_field][] = [
          'plugin' => 'social_media_links',
        ];
        $array_config['pseudo_' . $data_field['destiny']][] = [
          'plugin' => 'skip_on_empty',
          'source' => ['@pseudo_' . $origin_field],
          'method' => 'process',
        ];
        $array_config['pseudo_' . $data_field['destiny']][] = [
          'plugin' => 'reset_arrays',
        ];
        $array_config[$data_field['destiny']][] = [
          'plugin' => 'skip_on_empty',
          'source' => '@pseudo_' . $data_field['destiny'],
          'method' => 'process',
        ];
        $array_config[$data_field['destiny']][] = [
          'plugin' => 'sub_process',
          'method' => 'process',
          'process' => ['link' => 'link', 'social' => 'social'],
        ];
      }
      else {
        $insert_value = [
          'plugin' => 'skip_on_empty',
          'source' => $origin_field,
          'method' => 'process',
        ];
        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], 'pseudo_' . $data_field['destiny'], 'pseudo_' . $origin_field, $insert_value);
        $wildcard_yml_config['process']['pseudo_' . $origin_field][] = [
          'plugin' => 'social_media_links',
        ];
        $wildcard_yml_config['process']['pseudo_' . $data_field['destiny']][0]['source'][] = '@pseudo_' . $origin_field;
      }
    }
    else {
      // @todo unserialize attributes d7, map to d10 and serialize
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field,
        'method' => 'process',
      ];
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'process' => [
          'uri' => 'url',
          'title' => 'title',
        ]
      ];
    }
    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
  }
}
